@@ -2,6 +2,7 @@ import asyncio
 import logging
 import random
 import ssl
+from ssl import SSLContext, PROTOCOL_TLS
 from typing import Optional, Union, Any
 from deprecation import deprecated
 from .buildin import Buildin
@@ -51,7 +52,7 @@ class Client(Buildin):
         self._pool_idx = 0
         self._reconnecting = False
         if ssl is True:
-            self._ssl = ssl.SSLContext(ssl.PROTOCOL_TLS)
+            self._ssl = SSLContext(PROTOCOL_TLS)
         elif ssl is False:
             self._ssl = None
         else:
